@@ -1,8 +1,11 @@
 extern crate cassandra_cpp;
+extern crate futures;
 
 mod help;
 
 use cassandra_cpp::*;
+use futures::Future;
+
 
 #[test]
 fn test_bind_by_name() {
@@ -20,8 +23,8 @@ fn test_bind_by_name() {
     for _ in 0..1000 {
         let result = session.execute(&schema_query).wait().unwrap();
         for row in result {
-            let name: String = row.get_col_by_name("column_name").unwrap();
-            let ftype: String = row.get_col_by_name("type").unwrap();
+            let name: String = row.get_by_name("column_name").unwrap();
+            let ftype: String = row.get_by_name("type").unwrap();
             // Actual values are not important; we're checking it doesn't panic or fail to return info.
 
             println!("{} {}", name, ftype);
